#define MSG_TIMEOUT "Przekroczony czas oczekiwania"
#define MSG_CAPABILITIES "Nie mona przecza capabilities"
#define MSG_CLIENT_CLOSED_CNX "Klient zamkn poczenie"
#define MSG_CLIENT_READ_ERR "Bd odczytu danych od klienta"
#define MSG_CANT_OPEN_CNX "Nie mona utworzy poczenia"
#define MSG_CANT_CREATE_DATA_SOCKET "Nie mona utworzy gniazda dla danych"
#define MSG_DEBUG_CLIENT_IS "Adres klienta to"
#define MSG_SYNTAX_ERROR_IP "Bd skadni w adresie IP"
#define MSG_PORT_SUCCESSFUL "komenda PORT powioda si"
#define MSG_ONLY_IPV4V6 "Tylko IPv4 oraz IPv6 s wspierane (1,2)"
#define MSG_ONLY_IPV4 "Tylko IPv4 jest wspierane (1)"
#define MSG_TIMEOUT_PARSER "Przekroczono czas oczekiwaniat - wpisuj szybciej nastpnym razem"
#define MSG_LINE_TOO_LONG "Linia zbyt duga"
#define MSG_LOG_OVERFLOW "Klient prbowa przepeni bufor lini polece"
#define MSG_GOODBYE "egnaj. Wgrae %llu oraz cigne %llu kbajtw."
#define MSG_DEBUG_COMMAND "Komenda"
#define MSG_IS_YOUR_CURRENT_LOCATION "to Twoja aktualna lokalizacja"
#define MSG_NOT_LOGGED_IN "Nie jeste aktualnie zalogowany"
#define MSG_AUTH_UNIMPLEMENTED "Rozszerzenia bezpieczestwa nie zaimplementowane"
#define MSG_NO_FILE_NAME "Brak nazwy pliku"
#define MSG_NO_DIRECTORY_NAME "Brak nazwy katalogu"
#define MSG_NO_RESTART_POINT "Brak punktu z ktrego ponawia"
#define MSG_ABOR_SUCCESS "Poniewa to widzisz komenda ABOR zakoczya si sukcesem"
#define MSG_MISSING_ARG "Brakuje argumentu"
#define MSG_GARBAGE_FOUND "Znaleziono mieci po informacji o wartoci"
#define MSG_VALUE_TOO_LARGE "Wartoc zbyt dua"
#define MSG_IDLE_TIME "Czas oczekiwania ustawiony na %lu sekund"
#define MSG_SITE_HELP "Nastpujce komendy SITE s obsugiwane"
#define MSG_BAD_CHMOD "Nieprawidowe prawa"
#define MSG_UNKNOWN_EXTENSION "jest nieznanym rozszerzeniem"
#define MSG_XDBG_OK "komenda XDBG powioda si, aktualny poziom debugowania to %d"
#define MSG_UNKNOWN_COMMAND "Nieznana komenda"
#define MSG_TIMEOUT_NOOP "Przekroczony czas oczekiwania (brak operacji w cigu %lu sekund)"
#define MSG_TIMEOUT_DATA "Przekroczony czas oczekiwania (brak nowych danych w cigu %lu sekund)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Jeste ju zalogowany"
#define MSG_ANY_PASSWORD "Dowolne haso zadziaa"
#define MSG_ANONYMOUS_LOGGED "Anonimowy uytkownik zalogowany"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonimowy uytkownik zalogowany w wirtualnym FTP"
#define MSG_USER_OK "Uytkownik %s OK. Wymagane haso"
#define MSG_CANT_DO_TWICE "Nie mona tego zrobi w aktualnej sesji"
#define MSG_UNABLE_SECURE_ANON "Nie mona uaktywni bezpiecznego anonimowego FTP"
#define MSG_BANDWIDTH_RESTRICTED "Twoje zuycie pasma jest ograniczone"
#define MSG_NO_PASSWORD_NEEDED "Nie potrzebuj adnego hasa, mj drogi, tchliwy anonimie"
#define MSG_NOTRUST "Wybacz ale nie mona Ci ufa"
#define MSG_WHOAREYOU "Prosz powiedz mi kim jeste"
#define MSG_AUTH_FAILED "Uwierzytelnienie nie powiodo si, wybacz"
#define MSG_AUTH_TOOMANY "Zbyt wiele niepowodze podczas uwierzytelniania"
#define MSG_NO_HOMEDIR "Katalog domowy jest niedostpny - przerywam"
#define MSG_NO_HOMEDIR2 "%s nie istnieje lub nie mona go odczyta"
#define MSG_START_SLASH "Startuje w /"
#define MSG_USER_GROUP_ACCESS "Uytkownik %s ma grupowy dostp do"
#define MSG_FXP_SUPPORT "Ten serwer wspiera transfer FXP"
#define MSG_RATIO "Musisz respektowa wspczynnik %u:%u (wgrane/pobrane)"
#define MSG_CHROOT_FAILED "Nie mona uaktywni bezpiecznego wizienia chroot()"
#define MSG_CURRENT_DIR_IS "OK. Aktualny katalog to %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualny, ograniczony katalog to %s"
#define MSG_IS_NOW_LOGGED_IN "%s jest teraz zalogowany"
#define MSG_CANT_CHANGE_DIR "Nie mona zmieni katalogu na %s"
#define MSG_PATH_TOO_LONG "cieka zbyt duga"
#define MSG_CANT_PASV "Nie mona utworzy pasywnego poczenia za pomoc tej starej komendy"
#define MSG_CANT_PASSIVE "Nie mona utworzy pasywnego poczenia"
#define MSG_PORTS_BUSY "Wszystkie zarezerwowane porty TCP s zajte"
#define MSG_GETSOCKNAME_DATA "Nie mona zidentyfikowa lokalnego gniazda danych"
#define MSG_GETPEERNAME "Nie mona zidentyfikowa lokalnego gniazda danych"
#define MSG_INVALID_IP "Wybacz, podano zy adres"
#define MSG_NO_EPSV "Prosz uyj klienta IPv6 zgodnego ze standardem obsugi EPSV"
#define MSG_BAD_PORT "Wybacz ale nie pocz si z portami < 1024"
#define MSG_NO_FXP "Otwieranie poczenia do %s zamiast do %s"
#define MSG_FXP "transfer FXP : z %s do %s"
#define MSG_NO_DATA_CONN "Poczenie danych nie istnieje"
#define MSG_ACCEPT_FAILED "Poczenie nie mogo zosta zaakceptowane"
#define MSG_ACCEPT_SUCCESS "Zaakceptowano poczenie danych"
#define MSG_CNX_PORT_FAILED "Nie mona otworzy poczenia danych do portu %d"
#define MSG_CNX_PORT "czenie z portem %d"
#define MSG_ANON_CANT_MKD "Wybacz, anonimowi uytkownicy nie mog tworzy katalogw"
#define MSG_ANON_CANT_RMD "Wybacz, anonimowi uytkownicy nie mog usuwa katalogw"
#define MSG_ANON_CANT_RENAME "Anonimowi uytkownicy nie mog przenosi/zmienia nazw plikw"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonimowi uytkownicy nie mog zmienia praw"
#define MSG_GLOB_NO_MEMORY "Zabrako pamici podczas rozwijania %s"
#define MSG_PROBABLY_DENIED "(To prawdopodobnie oznacza \"Brak dostpu\")"
#define MSG_GLOB_READ_ERROR "Bd odczytu podczas rozwijania %s"
#define MSG_GLOB_NO_MATCH "Brak pasujcych do %s w %s"
#define MSG_CHMOD_FAILED "Nie mona zmieni praw na %s"
#define MSG_CHMOD_SUCCESS "Prawa na %s zostay zmienione"
#define MSG_CHMOD_TOTAL_FAILURE "Wybacz ale nie mona byo zmieni adnego prawa"
#define MSG_ANON_CANT_DELETE "Anonimowi uytkownicy nie mog kasowa plikw"
#define MSG_ANON_CANT_OVERWRITE "Anonimowi uytkownicy nie mog nadpisywa istniejcych plikw"
#define MSG_DELE_FAILED "Nie mona skasowa %s"
#define MSG_DELE_SUCCESS "Skasowano %s"
#define MSG_DELE_TOTAL_FAILURE "Nie skasowano adnego pliku"
#define MSG_LOAD_TOO_HIGH \
    "Obcienie systemu wynnosio %3.2f w momencie Twojego zalogowania. Nie pozwalamy\n" \
    "anonimowym uytkownikom na pobieranie plikw przy tak duym obcieniu systemu.\n" \
    "Wgrywanie jest zawsze dozwolone."
#define MSG_OPEN_FAILURE "Nie mona otworzy %s"
#define MSG_OPEN_FAILURE2 "Nie mona otworzy tego pliku"
#define MSG_STAT_FAILURE "Nie mona uzyska wielkoci pliku"
#define MSG_STAT_FAILURE2 "Nie mona sprawdzi czy plik istnieje"
#define MSG_REST_TOO_LARGE_FOR_FILE "Przesunicie podczas wznawiania %lld jest zbyt due dla pliku o wielkoci %lld."
#define MSG_REST_RESET "Przesunicie podczas wznawiania ustawione na 0"
#define MSG_NOT_REGULAR_FILE "Mona przesya wycznie regularne pliki"
#define MSG_NOT_MODERATED \
    "Ten plik zosta wgrany przez anonimowego uytkownika i nie zosta zatwierdzony\n" \
    "przez administratora do cigania."
#define MSG_RATIO_DENIAL \
    "Wybacz ale wspczynnik wgrywania/cigania to %u:%u .\n" \
    "Aktualnie wgrae %llu Kb i cigne %llu Kb.\n" \
    "Prosz wgraj jakie dane i sprbuj cign pniej."
#define MSG_NO_MORE_TO_DOWNLOAD "Nie pozostao nic do cigania"
#define MSG_WINNER "Komputer jest Twoim przyjacielem. Zaufaj mu"
#define MSG_KBYTES_LEFT "%.1f kbajtw do cignicia"
#define MSG_ABORTED "Transfer przerwano"
#define MSG_DATA_WRITE_FAILED "Bd podczas pisania danych do poczenia dla danych"
#define MSG_DATA_READ_FAILED "Bd podczas odczytu danych z poczenia dla danych"
#define MSG_MMAP_FAILED "Nie mona zmapowa pliku do pamici"
#define MSG_WRITE_FAILED "Bd podczas zapisu do pliku"
#define MSG_TRANSFER_RATE_M "%.3f sekund (zmierzonych tutaj), %.2f Mbajtw na sekund"
#define MSG_TRANSFER_RATE_K "%.3f sekund (zmierzonych tutaj), %.2f Kbajtw na sekund"
#define MSG_TRANSFER_RATE_B "%.3f sekund (zmierzonych tutaj), %.2f bajtw na sekund"
#define MSG_SPACE_FREE_M "%.1f Mbajtw wolnej przestrzeni dyskowej"
#define MSG_SPACE_FREE_K "%f Kbajtw wolnej przestrzeni dyskowej"
#define MSG_DOWNLOADED "cignito"
#define MSG_REST_NOT_NUMERIC "REST wymaga numerycznego parametru"
#define MSG_REST_ASCII_STRICT "Znacznik odpowiedzi musi by ustawiony na 0 w trybie ASCII"
#define MSG_REST_ASCII_WORKAROUND "Wznawiam od %lld ale jestemy w trybie ASCII"
#define MSG_REST_SUCCESS "Wznawiam od %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Niedozwolona nazwa katalogu"
#define MSG_SANITY_FILE_FAILURE "Niedozwolona nazwa pliku: %s"
#define MSG_MKD_FAILURE "Nie mona utworzy katalogu"
#define MSG_MKD_SUCCESS "Utworzono katalog"
#define MSG_RMD_FAILURE "Nie mona usun katalogu"
#define MSG_RMD_SUCCESS "Katalog zosta usunity"
#define MSG_TIMESTAMP_FAILURE "Nie mona uzyska znacznika czasu"
#define MSG_MODE_ERROR "Tylko tryby ASCII i binarny s wspierane"
#define MSG_CREATE_FAILURE "Nie mona utworzy pliku"
#define MSG_ABRT_ONLY "ABRT jest prawidow komend tylko podczas wgrywania"
#define MSG_UPLOAD_PARTIAL "czciowo wgrano"
#define MSG_REMOVED "zmieniono nazw"
#define MSG_UPLOADED "wgrano"
#define MSG_GMTIME_FAILURE "Nie mona uzyska lokalnego czasu"
#define MSG_TYPE_8BIT_FAILURE "Tylko 8-bitowe bajty s wspierane, nie yjemy 10 lat temu"
#define MSG_TYPE_UNKNOWN "Nieznany TYP"
#define MSG_TYPE_SUCCESS "TYP to aktualnie"
#define MSG_STRU_FAILURE "Tylko Pliki (\"F\"iles) s wspierane"
#define MSG_MODE_FAILURE "Prosz uyj trybu S(trumieniowego)"
#define MSG_RENAME_ABORT "Anulowanie poprzedniej operacji zmiany nazwy"
#define MSG_RENAME_RNFR_SUCCESS "RNFR zaakceptowane - plik istnieje, gotw do przeznaczenia"
#define MSG_FILE_DOESNT_EXIST "Wybacz ale taki plik nie istnieje"
#define MSG_RENAME_ALREADY_THERE "RENAME Niepowiodo si - plik docelowy ju istnieje"
#define MSG_RENAME_NORNFR "Potrzeba RNFR przed RNTO"
#define MSG_RENAME_FAILURE "Usuwanie/zmiana nazwy nie powioda si"
#define MSG_RENAME_SUCCESS "Zmieniono lub przeniesiono plik"
#define MSG_NO_SUPERSERVER "Prosz uruchom pure-ftpd z serwerem nadrzdnym (takim jak tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nie mona znale konta 'ftp'"
#define MSG_CONF_ERR "Bd konfiguracji"
#define MSG_NO_VIRTUAL_FILE "Brakuje nazwy pliku wirtualnych uytkownikw"
#define MSG_ILLEGAL_THROTTLING "Nieprawidowa warto dla limitu pasma"
#define MSG_ILLEGAL_TRUSTED_GID "Nieprawidowy zaufany gid dla chroota"
#define MSG_ILLEGAL_USER_LIMIT "Nieprawidowy limit uytkownikw"
#define MSG_ILLEGAL_FACILITY "Nieznana nazwa facility"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Nieprawidowy plik konfiguracyjny LDAP"
#define MSG_ILLEGAL_LOAD_LIMIT "Nieprawidowy limit load"
#define MSG_ILLEGAL_PORTS_RANGE "Nieprawidowy przedzia portw"
#define MSG_ILLEGAL_LS_LIMITS "Nieprawidowy limit 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Niepdawidowe IP wymuszone dla pasywnych pocze"
#define MSG_ILLEGAL_RATIO "Nieprawidowy wspczynnik dotyczcy cigania/wgrywania"
#define MSG_ILLEGAL_UID_LIMIT "Nieprawidowy limit uid"
#define MSG_ILLEGAL_OPTION "Nieznana opcja"
#define MSG_LDAP_MISSING_BASE "Brakuje LDAPBaseDN w pliku konfiguracyjnym LDAP"
#define MSG_LDAP_WRONG_PARMS "Bdne parametry LDAP"
#define MSG_NEW_CONNECTION "Nowe poczenie z %s"
#define MSG_WELCOME_TO "Witaj na"
#define MSG_MAX_USERS "%lu uytkownikw (maksimum) ju zalogowanych, wybacz"
#define MSG_NB_USERS "Jeste %d uytkownikiem z %d moliwych"
#define MSG_WELCOME_TIME "Lokalny czas: %02d:%02d. Port serwera: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Wycznie anonimowe FTP jest dozwolone"
#define MSG_RATIOS_EVERYONE "WSPӣCZYNNIK OBEJMUJE WSZYSTKICH UYTKOWNIKW :"
#define MSG_RATIOS_ANONYMOUS "ANONIMOWYCH UYTKOWNIKW OBEJMUJE WSPӣCZYNNIK UL/DL :"
#define MSG_RATIOS_RULE "by cign %u Mb, musisz wgra %u Mb danych."
#define MSG_INFO_IDLE_M "Zostaniesz rozczony po %lu minutach nieaktywnoci."
#define MSG_INFO_IDLE_S "Zostaniesz rozczony po %lu sekundach nieaktywnoci."
#define MSG_CANT_READ_FILE "Niestety, nie mona byo przeczyta [%s]"
#define MSG_LS_TRUNCATED "Wyjcie obcite do %u pasujcych"
#define MSG_LS_SUCCESS "%u w sumie pasujcych"
#define MSG_LOGOUT "Wylogowywanie."
#define MSG_AUTH_FAILED_LOG "Autentyfikacja nie powioda si dla uytkownika [%s]"
#define MSG_ILLEGAL_UMASK "Nieprawidowa umask"
#define MSG_STANDALONE_FAILED "Nie mona wystartowa w trybie standalone"
#define MSG_NO_ANONYMOUS_LOGIN "To jest prywatny system - Bez anonimowych logowa"
#define MSG_ANONYMOUS_ANY_PASSWORD "Dowolne haso zadziaa"
#define MSG_MAX_USERS_IP "Zbyt wiele pocze (%lu) z tego IP"
#define MSG_ACTIVE_DISABLED "Tryb aktywny jest zablokowany"
#define MSG_TRANSFER_SUCCESSFUL "Przesy pliku zakoczony sukcesem"
#define MSG_NO_DISK_SPACE "Dysk peny - prosz wgraj pniej"
#define MSG_OUT_OF_MEMORY "Zabrako pamici"
#define MSG_SQL_WRONG_PARMS "Bdne parametry SQL"
#define MSG_ILLEGAL_TRUSTED_IP "Nieprawidowy zaufany adres IP"
#define MSG_NO_ASCII_RESUME "Wznawianie transferu ASCII nie jest bezpieczne, prosz najpierw usu plik"
#define MSG_UNKNOWN_ALTLOG "Nieznany format logw"
#define MSG_ACCOUNT_DISABLED "Nie mona zalogowa si jako [%s] : konto zablokowane"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Nieprawidowy plik konfiguracji SQL"
#define MSG_SQL_MISSING_SERVER "W konfiguracji SQL brakuje serwera"
#define MSG_SQL_DOWN "Serwer SQL jest prawdopodobnie niedostpny" 
#define MSG_ILLEGAL_QUOTA "Nieprawidowa quota"
#define MSG_QUOTA_FILES "%llu plikw uytych (%d%%) - autoryzowano: %llu plikw"
#define MSG_QUOTA_SIZE "%llu Kbajtw uytych (%d%%) - autoryzowano: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Przekroczona quota: [%s] nie zostanie zapisany"
#define MSG_AUTH_UNKNOWN "Nieznana metoda autentyfikacji"
#define MSG_PDB_BROKEN "Nie udao si odczyta indeksowanego pliku puredb (lub wykryto stary format) - Sprbuj uruchomi pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s is an alias for %s."
#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
#define MSG_ALIASES_LIST "The following aliases are available :"
#define MSG_PERUSER_MAX "I can't accept more than %lu connections from the same user"
#define MSG_IPV6_OK "IPv6 connections are also welcome on this server"
#define MSG_TLS_INFO "SSL/TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "SSL/TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using SSL/TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
